"use strict";

import { Platform } from 'react-native';
import { EmbeddedComponent } from '@notabene/javascript-sdk';
import { NotabeneSdk } from "./notabene-sdk.js";
export class EmbeddedComponentRN extends EmbeddedComponent {
  constructor(url, deepLink, value) {
    super(url, value);
    this.deepLink = deepLink;
  }
  async openModal() {
    try {
      const response = await openComponent(this.url, this.deepLink);
      const [deepLink, fragment] = response.split('#');
      const params = new URLSearchParams(fragment);
      const encodedMessage = params.has('message') ? params.get('message') : undefined;
      const transactionResponse = {
        ...(encodedMessage ? [JSON.parse(encodedMessage)] : [{}]),
        _deepLink: `${deepLink}#${fragment}`
      };
      return transactionResponse;
    } catch (ex) {
      const error = ex;
      if (error.message?.includes('The operation couldn’t be completed')) {
        return Promise.reject('User cancellation');
      }
      return Promise.reject(error);
    }
  }
}
async function openComponent(url, deepLink) {
  if (Platform.OS !== 'ios') {
    return Promise.reject('AuthSession is only supported on iOS');
  }
  return await NotabeneSdk.open(url, deepLink);
}
//# sourceMappingURL=embedded-component.js.map