import { Platform } from 'react-native';
import {
  EmbeddedComponent,
  type TransactionResponse,
} from '@notabene/javascript-sdk';
import { NotabeneSdk } from './notabene-sdk';

export class EmbeddedComponentRN<V, O> extends EmbeddedComponent<V, O> {
  deepLink: string;
  constructor(url: string, deepLink: string, value: Partial<V>) {
    super(url, value);
    this.deepLink = deepLink;
  }

  async openModal(): Promise<TransactionResponse<V>> {
    try {
      const response = await openComponent(this.url, this.deepLink);
      const [deepLink, fragment] = response.split('#');
      const params = new URLSearchParams(fragment);
      const encodedMessage = params.has('message')
        ? params.get('message')
        : undefined;

      const transactionResponse = {
        ...(encodedMessage ? [JSON.parse(encodedMessage)] : [{}]),
        _deepLink: `${deepLink}#${fragment}`,
      } as unknown as TransactionResponse<V>;

      return transactionResponse;
    } catch (ex) {
      const error = ex as Error;
      if (error.message?.includes('The operation couldn’t be completed')) {
        return Promise.reject('User cancellation');
      }
      return Promise.reject(error);
    }
  }
}

async function openComponent(url: string, deepLink: string): Promise<string> {
  if (Platform.OS !== 'ios') {
    return Promise.reject('AuthSession is only supported on iOS');
  }
  return await NotabeneSdk.open(url, deepLink);
}
